## Prototype for Swedeb Demo.

Based on Streamlit

To run


`streamlit run swedeb_demo/main_page_shared_filter.py`

To run with .env file (specifying a corpus)


`streamlit run swedeb_demo/main_page_shared_filter.py -- --env_file .env`

To run without displaying the "debug" tab


`streamlit run swedeb_demo/main_page_shared_filter.py -- --debug False`